package com.ruoyi.bst.storeStaff.mapper;

import java.util.List;
import com.ruoyi.bst.storeStaff.domain.StoreStaff;
import com.ruoyi.bst.storeStaff.domain.StoreStaffVO;
import com.ruoyi.bst.storeStaff.domain.StoreStaffQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 员工运维Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-15
 */
public interface StoreStaffMapper
{
    /**
     * 查询员工运维
     *
     * @param id 员工运维主键
     * @return 员工运维
     */
    StoreStaffVO selectStoreStaffById(Long id);

    /**
     * 查询员工运维列表
     *
     * @param query 员工运维
     * @return 员工运维集合
     */
    List<StoreStaffVO> selectStoreStaffList(@Param("query")StoreStaffQuery query);

    /**
     * 新增员工运维
     *
     * @param storeStaff 员工运维
     * @return 结果
     */
    int insertStoreStaff(StoreStaff storeStaff);

    /**
     * 批量新增员工运维
     */
    int batchInsert(@Param("list") List<? extends StoreStaff> list);

    /**
     * 批量修改员工运维
     */
    int batchUpdate(@Param("list") List<? extends StoreStaff> list);

    /**
     * 修改员工运维
     *
     * @param storeStaff 员工运维
     * @return 结果
     */
    public int updateStoreStaff(@Param("data") StoreStaff storeStaff);

    /**
     * 删除员工运维
     *
     * @param id 员工运维主键
     * @return 结果
     */
    int deleteStoreStaffById(Long id);

    /**
     * 批量删除员工运维
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStoreStaffByIds(Long[] ids);

    List<Long> selectIdList(@Param("query") StoreStaffQuery query);

    int selectCount(@Param("query") StoreStaffQuery query);
}
